/***************************************************************** 
 * FILE        : vybrid_i2c.h
 * 
 * DESCRIPTION : This is the header file describing the register
 *               set for:
 *               FARADAY
 *
 *               Please enter any bugs on GFORGE:
 * 				 http://gforge.freescale.net/projects/faraday-header/
 *				 Ensure you are logged in to enter bugs (top right of screen  use OneIT pass).
 *				 Tracker -> Bugs -> Submit New
 *				 Only the title (including the header name e.g. ADC.h) and description are 
 * 			 	 required  the rest can be left as default. 
 *				
 *               Alternatively send bugs to b06321@freescale.com
 *               using [FARADAY_HEADER] in subject         
 * 
 * COPYRIGHT   :(c) 2011, Freescale Semiconductor
 * 
 * VERSION     : 0
 * DATE        : 07 September 2011
 * AUTHOR      : b06321 
 * HISTORY     : 
 * v0: 	Alpha release made up from currently available BG. Not yet  
 * 		fully tested. Regs and bits are liable to change up until
 * 		tape-out.
 * 
 *
 ******************************************************************/
 
 /* ================================================================================
   ==============================        I2C         ==============================  
   ================================================================================ */
#ifndef I2C_H
#define I2C_H
#include "typedefs.h"

/* I2C - Peripheral register structure */
typedef struct I2C_MemMap {
  vuint8_t IBAD;               /* offset: 0x00*/
  vuint8_t IBFD;               /* offset: 0x01*/
  vuint8_t IBCR;               /* offset: 0x02*/
  vuint8_t IBSR;               /* offset: 0x03*/
  vuint8_t IBDR;               /* offset: 0x04*/
  vuint8_t IBIC;               /* offset: 0x05*/
  vuint8_t IBDBG;               /* offset: 0x06*/
} volatile *I2C_MemMapPtr;



/* I2C - Register offsets */
#define I2C_IBAD_OFFSET                 0x00
#define I2C_IBFD_OFFSET                 0x01
#define I2C_IBCR_OFFSET                 0x02
#define I2C_IBSR_OFFSET                 0x03
#define I2C_IBDR_OFFSET                 0x04
#define I2C_IBIC_OFFSET                 0x05
#define I2C_IBDBG_OFFSET                0x06

/* I2C Register per module */
#define I2C0_IBAD                        (I2C0_BASE + I2C_IBAD_OFFSET)
#define I2C0_IBFD                        (I2C0_BASE + I2C_IBFD_OFFSET)
#define I2C0_IBCR                        (I2C0_BASE + I2C_IBCR_OFFSET)
#define I2C0_IBSR                        (I2C0_BASE + I2C_IBSR_OFFSET)
#define I2C0_IBDR                        (I2C0_BASE + I2C_IBDR_OFFSET)
#define I2C0_IBIC                        (I2C0_BASE + I2C_IBIC_OFFSET)
#define I2C0_IBDBG                       (I2C0_BASE + I2C_IBDBG_OFFSET)

#define I2C1_IBAD                        (I2C1_BASE + I2C_IBAD_OFFSET)
#define I2C1_IBFD                        (I2C1_BASE + I2C_IBFD_OFFSET)
#define I2C1_IBCR                        (I2C1_BASE + I2C_IBCR_OFFSET)
#define I2C1_IBSR                        (I2C1_BASE + I2C_IBSR_OFFSET)
#define I2C1_IBDR                        (I2C1_BASE + I2C_IBDR_OFFSET)
#define I2C1_IBIC                        (I2C1_BASE + I2C_IBIC_OFFSET)
#define I2C1_IBDBG                       (I2C1_BASE + I2C_IBDBG_OFFSET)

#define I2C2_IBAD                        (I2C2_BASE + I2C_IBAD_OFFSET)
#define I2C2_IBFD                        (I2C2_BASE + I2C_IBFD_OFFSET)
#define I2C2_IBCR                        (I2C2_BASE + I2C_IBCR_OFFSET)
#define I2C2_IBSR                        (I2C2_BASE + I2C_IBSR_OFFSET)
#define I2C2_IBDR                        (I2C2_BASE + I2C_IBDR_OFFSET)
#define I2C2_IBIC                        (I2C2_BASE + I2C_IBIC_OFFSET)
#define I2C2_IBDBG                       (I2C2_BASE + I2C_IBDBG_OFFSET)

#define I2C3_IBAD                        (I2C3_BASE + I2C_IBAD_OFFSET)
#define I2C3_IBFD                        (I2C3_BASE + I2C_IBFD_OFFSET)
#define I2C3_IBCR                        (I2C3_BASE + I2C_IBCR_OFFSET)
#define I2C3_IBSR                        (I2C3_BASE + I2C_IBSR_OFFSET)
#define I2C3_IBDR                        (I2C3_BASE + I2C_IBDR_OFFSET)
#define I2C3_IBIC                        (I2C3_BASE + I2C_IBIC_OFFSET)
#define I2C3_IBDBG                       (I2C3_BASE + I2C_IBDBG_OFFSET)

/* Field definitions for IBAD */
#define I2C_IBAD_ADR_SHIFT              (1)
#define I2C_IBAD_ADR_MASK               ((0x7F) << (I2C_IBAD_ADR_SHIFT)) 



/* Field definitions for IBFD */
#define I2C_IBFD_IBC_SHIFT              (0)
#define I2C_IBFD_IBC_MASK               ((0xFF) << (I2C_IBFD_IBC_SHIFT)) 



/* Field definitions for IBCR */
#define I2C_IBCR_MDIS_SHIFT             (7)  
#define I2C_IBCR_MDIS_MASK              ((1) << (I2C_IBCR_MDIS_SHIFT)) 

#define I2C_IBCR_IBIE_SHIFT             (6)  
#define I2C_IBCR_IBIE_MASK              ((1) << (I2C_IBCR_IBIE_SHIFT)) 

#define I2C_IBCR_MSSL_SHIFT            (5)  
#define I2C_IBCR_MSSL_MASK             ((1) << (I2C_IBCR_MSSL_SHIFT)) 

#define I2C_IBCR_TXRX_SHIFT            (4)  
#define I2C_IBCR_TXRX_MASK             ((1) << (I2C_IBCR_TXRX_SHIFT)) 

#define I2C_IBCR_NOACK_SHIFT            (3)  
#define I2C_IBCR_NOACK_MASK             ((1) << (I2C_IBCR_NOACK_SHIFT)) 

#define I2C_IBCR_RSTA_SHIFT             (2)  
#define I2C_IBCR_RSTA_MASK              ((1) << (I2C_IBCR_RSTA_SHIFT)) 

#define I2C_IBCR_DMAEN_SHIFT            (1)  
#define I2C_IBCR_DMAEN_MASK             ((1) << (I2C_IBCR_DMAEN_SHIFT)) 

#define I2C_IBCR_IBSDOZE_SHIFT           (0)  
#define I2C_IBCR_IBSDOZE_MASK            ((1) << (I2C_IBCR_IBSDOZE_SHIFT)) 



/* Field definitions for IBSR */
#define I2C_IBSR_TCF_SHIFT              (7)  
#define I2C_IBSR_TCF_MASK               ((1) << (I2C_IBSR_TCF_SHIFT)) 

#define I2C_IBSR_IAAS_SHIFT             (6)  
#define I2C_IBSR_IAAS_MASK              ((1) << (I2C_IBSR_IAAS_SHIFT)) 

#define I2C_IBSR_IBB_SHIFT              (5)  
#define I2C_IBSR_IBB_MASK               ((1) << (I2C_IBSR_IBB_SHIFT)) 

#define I2C_IBSR_IBAL_SHIFT             (4)  
#define I2C_IBSR_IBAL_MASK              ((1) << (I2C_IBSR_IBAL_SHIFT)) 

#define I2C_IBSR_SRW_SHIFT              (2)  
#define I2C_IBSR_SRW_MASK               ((1) << (I2C_IBSR_SRW_SHIFT)) 

#define I2C_IBSR_IBIF_SHIFT             (1)  
#define I2C_IBSR_IBIF_MASK              ((1) << (I2C_IBSR_IBIF_SHIFT)) 

#define I2C_IBSR_RXAK_SHIFT             (0)  
#define I2C_IBSR_RXAK_MASK              ((1) << (I2C_IBSR_RXAK_SHIFT)) 



/* Field definitions for IBDR */
#define I2C_IBDR_DATA_SHIFT             (0)
#define I2C_IBDR_DATA_MASK              ((0xFF) << (I2C_IBDR_DATA_SHIFT)) 



/* Field definitions for IBIC */
#define I2C_IBIC_BIIE_SHIFT             (7)  
#define I2C_IBIC_BIIE_MASK              ((1) << (I2C_IBIC_BIIE_SHIFT)) 



/* Field definitions for IBDBG */
#define I2C_IBDBG_IPG_DEBUG_HALTED_SHIFT             (1)  
#define I2C_IBDBG_IPG_DEBUG_HALTED_MASK              ((1) << (I2C_IBDBG_IPG_DEBUG_HALTED_SHIFT)) 

#define I2C_IBDBG_IPG_DEBUG_EN_SHIFT             (0)  
#define I2C_IBDBG_IPG_DEBUG_EN_MASK              ((1) << (I2C_IBDBG_IPG_DEBUG_EN_SHIFT)) 

/*** End of bit definitions ***/

/*** define base address ***/
#define I2C0_BASE		0x40066000
#define I2C1_BASE		0x40067000
#define I2C2_BASE		0x400E6000
#define I2C3_BASE		0x400E7000

#define I2C0                    ( ( I2C_MemMapPtr ) I2C0_BASE )
#define I2C1                    ( ( I2C_MemMapPtr ) I2C0_BASE )
#define I2C2                    ( ( I2C_MemMapPtr ) I2C0_BASE )
#define I2C3                    ( ( I2C_MemMapPtr ) I2C0_BASE )

#endif
